Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(861)

Unified Diff: src/objects.h

Issue 555783002: Don't record slots of objects that may contain raw values. (Closed) Base URL: https://v8.googlecode.com/svn/branches/bleeding_edge
Patch Set: Created 6 years, 3 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « src/heap/store-buffer.cc ('k') | src/objects-inl.h » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: src/objects.h
diff --git a/src/objects.h b/src/objects.h
index e2fac8ef9f128a765fb50d2024a47773a3b7ba2b..75cff5759dc8feeff72af3c80e84b7cc9811b8f0 100644
--- a/src/objects.h
+++ b/src/objects.h
@@ -1740,9 +1740,9 @@ class HeapObject: public Object {
// Returns the heap object's size in bytes
inline int Size();
- // Returns true if this heap object may contain pointers to objects in new
- // space.
- inline bool MayContainNewSpacePointers();
+ // Returns true if this heap object may contain raw values, i.e., values that
+ // look like pointers to heap objects.
+ inline bool MayContainRawValues();
// Given a heap object's map pointer, returns the heap size in bytes
// Useful when the map pointer field is used for other purposes.
« no previous file with comments | « src/heap/store-buffer.cc ('k') | src/objects-inl.h » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698